pub struct DeviceConfigurationProto {
pub name: String,
pub num_devices: i32,
pub device: Vec<String>,
}Expand description
DeviceConfigurationProto describes a multi-device configuration for a model.
Fields
name: StringThis field MUST be present for this version of the IR. Name of the configuration.
num_devices: i32This field MUST be present for this version of the IR. Number of devices inside this configuration.
device: Vec<String>Optional names of the devices. MUST be length of num_devices if provided.