pub struct FunctionProto {
pub name: String,
pub input: Vec<String>,
pub output: Vec<String>,
pub attribute: Vec<String>,
pub attribute_proto: Vec<AttributeProto>,
pub node: Vec<NodeProto>,
pub doc_string: String,
pub opset_import: Vec<OperatorSetIdProto>,
pub domain: String,
pub overload: String,
pub value_info: Vec<ValueInfoProto>,
pub metadata_props: Vec<StringStringEntryProto>,
}Fields
name: StringThe name of the function, similar to op_type in NodeProto. This is part of the unique-id (domain, name, overload) of FunctionProtos in a model.
input: Vec<String>The inputs and outputs of the function.
output: Vec<String>attribute: Vec<String>The attribute parameters of the function. It is for function parameters without default values.
attribute_proto: Vec<AttributeProto>The attribute protos of the function. It is for function attributes with default values. A function attribute shall be represented either as a string attribute or an AttributeProto, not both.
node: Vec<NodeProto>The nodes in the function.
doc_string: StringA human-readable documentation for this function. Markdown is allowed.
opset_import: Vec<OperatorSetIdProto>domain: StringThe domain which this function belongs to. This is part of the unique-id (domain, name, overload) of FunctionProtos in a model.
overload: StringThe overload identifier of the function. This is part of the unique-id (domain, name, overload) of FunctionProtos in a model.
value_info: Vec<ValueInfoProto>Information for the values in the function. The ValueInfoProto.name’s must be distinct and refer to names in the function (including inputs, outputs, and intermediate values). It is optional for a value to appear in value_info list.
metadata_props: Vec<StringStringEntryProto>Named metadata values; keys should be distinct.